@@ -7,6 +7,7 @@ from rich import box
 from rich.console import Console
 from rich.logging import RichHandler
 from rich.markdown import Markdown
+from rich.panel import Panel
 from rich.table import Table
 from rich.theme import Theme
 
@@ -31,35 +32,38 @@ logging.basicConfig(
 LOG = logging.getLogger(__name__)
 
 
-def print_results(project_type, results, pkg_aliases, sug_version_dict):
-    """Pretty print report summary
-    """
-    if not len(results):
+def print_results(project_type, results, pkg_aliases, sug_version_dict, scoped_pkgs):
+    """Pretty print report summary"""
+    if not results:
         return
     table = Table(
         title=f"Dependency Scan Results ({project_type})",
         box=box.DOUBLE_EDGE,
         header_style="bold magenta",
     )
+    required_pkgs = scoped_pkgs.get("required", [])
+    optional_pkgs = scoped_pkgs.get("optional", [])
+    pkg_attention_count = 0
+    fix_version_count = 0
     for h in [
         "Id",
         "Package",
+        "Used?",
         "Version",
         "Fix Version",
         "Severity",
         "Score",
-        "Description",
     ]:
         justify = "left"
         if h == "Score":
             justify = "right"
         width = None
         if h == "Id":
-            width = 15
-        elif h == "Fix Version":
+            width = 20
+        elif h == "Used?" or h == "Fix Version":
             width = 10
         elif h == "Description":
-            width = 60
+            width = 58
         table.add_column(header=h, justify=justify, width=width, no_wrap=False)
     for res in results:
         vuln_occ_dict = res.to_dict()
@@ -73,27 +77,61 @@ def print_results(project_type, results, pkg_aliases, sug_version_dict):
             )
         # De-alias package names
         full_pkg = pkg_aliases.get(full_pkg, full_pkg)
-        package = full_pkg.split(":")[-1]
         fixed_location = sug_version_dict.get(full_pkg, package_issue.fixed_location)
+        package_usage = "N/A"
+        package_name_style = ""
+        id_style = ""
+        pkg_severity = vuln_occ_dict.get("severity")
+        if full_pkg in required_pkgs and pkg_severity in ("CRITICAL", "HIGH"):
+            id_style = ":point_right: "
+            pkg_attention_count = pkg_attention_count + 1
+            if fixed_location:
+                fix_version_count = fix_version_count + 1
+        if full_pkg in required_pkgs:
+            package_usage = "[bright_green][bold]Yes"
+            package_name_style = "[bold]"
+        elif full_pkg in optional_pkgs:
+            package_usage = "[magenta]No"
+            package_name_style = "[italic]"
+        package = full_pkg.split(":")[-1]
         table.add_row(
-            "{}{}".format(
-                "[bright_red]" if vuln_occ_dict.get("severity") == "CRITICAL" else "",
+            "{}{}{}{}".format(
+                id_style,
+                package_name_style,
+                "[bright_red]" if pkg_severity == "CRITICAL" else "",
                 id,
             ),
-            package,
+            "{}{}".format(package_name_style, package),
+            package_usage,
             package_issue.affected_location.version,
             fixed_location,
             "{}{}".format(
-                "[bright_red]" if vuln_occ_dict.get("severity") == "CRITICAL" else "",
+                "[bright_red]" if pkg_severity == "CRITICAL" else "",
                 vuln_occ_dict.get("severity"),
             ),
             "{}{}".format(
-                "[bright_red]" if vuln_occ_dict.get("severity") == "CRITICAL" else "",
+                "[bright_red]" if pkg_severity == "CRITICAL" else "",
                 vuln_occ_dict.get("cvss_score"),
             ),
-            Markdown(vuln_occ_dict.get("short_description")),
         )
     console.print(table)
+    if scoped_pkgs:
+        if pkg_attention_count:
+            rmessage = f":heavy_exclamation_mark: [magenta]{pkg_attention_count}[/magenta] out of {len(results)} vulnerabilities requires your attention."
+            if fix_version_count:
+                if fix_version_count == pkg_attention_count:
+                    rmessage += "\n:white_heavy_check_mark: You can update [bright_green]all[/bright_green] the packages using the mentioned fix version to remediate."
+                else:
+                    rmessage += "\nYou can remediate [bright_green]{fix_version_count}[/bright_green] vulnerabilities by updating the packages using the fix version :thumbsup:."
+            console.print(Panel(rmessage, title="Recommendation", expand=False,))
+        else:
+            console.print(
+                Panel(
+                    ":white_check_mark: No package requires immediate attention since the major vulnerabilities are found only in dev packages and indirect dependencies.",
+                    title="Recommendation",
+                    expand=False,
+                )
+            )
 
 
 def analyse(project_type, results):
@@ -127,7 +165,9 @@ def analyse(project_type, results):
     return summary
 
 
-def jsonl_report(project_type, results, pkg_aliases, sug_version_dict, out_file_name):
+def jsonl_report(
+    project_type, results, pkg_aliases, sug_version_dict, scoped_pkgs, out_file_name
+):
     """Produce vulnerability occurrence report in jsonl format
 
     :param project_type: Project type
@@ -135,6 +175,9 @@ def jsonl_report(project_type, results, pkg_aliases, sug_version_dict, out_file_
     :param pkg_aliases: Package alias
     :param out_file_name: Output filename
     """
+    required_pkgs = scoped_pkgs.get("required", [])
+    optional_pkgs = scoped_pkgs.get("optional", [])
+    excluded_pkgs = scoped_pkgs.get("excluded", [])
     with open(out_file_name, "w") as outfile:
         for data in results:
             vuln_occ_dict = data.to_dict()
@@ -151,9 +194,17 @@ def jsonl_report(project_type, results, pkg_aliases, sug_version_dict, out_file_
             fixed_location = sug_version_dict.get(
                 full_pkg, package_issue.fixed_location
             )
+            package_usage = "N/A"
+            if full_pkg in required_pkgs:
+                package_usage = "required"
+            elif full_pkg in optional_pkgs:
+                package_usage = "optional"
+            elif full_pkg in excluded_pkgs:
+                package_usage = "excluded"
             data_obj = {
                 "id": id,
                 "package": full_pkg,
+                "package_usage": package_usage,
                 "version": package_issue.affected_location.version,
                 "fix_version": fixed_location,
                 "severity": vuln_occ_dict.get("severity"),
@@ -208,8 +259,7 @@ def analyse_licenses(project_type, licenses_results, license_report_file=None):
 
 
 def suggest_version(results, pkg_aliases={}):
-    """Provide version suggestions
-    """
+    """Provide version suggestions"""
     pkg_fix_map = {}
     sug_map = {}
     if not pkg_aliases:
