@@ -4,8 +4,7 @@ from depscan.lib.utils import find_files
 
 
 def build_license_data(license_dir):
-    """
-    """
+    """Build license data based on the txt files"""
     licenses_dict = {}
     license_files = find_files(license_dir, "txt")
     for lfile in license_files:
@@ -28,10 +27,12 @@ def build_license_data(license_dir):
 
 
 def bulk_lookup(license_dict, pkg_list):
-    """
-    """
+    """Lookup package licenses"""
     pkg_licenses = {}
     for pkg in pkg_list:
+        # Failsafe in case the bom file contains incorrect entries
+        if not pkg.get("name") or not pkg.get("version"):
+            continue
         pkg_key = pkg["name"] + "@" + pkg["version"]
         if pkg.get("vendor"):
             pkg_key = pkg.get("vendor") + ":" + pkg["name"] + "@" + pkg["version"]
