@@ -53,18 +53,22 @@ def create_pkg_variations(pkg_dict):
                 if tmpA[1] != name:
                     vendor_aliases.add(tmpA[1])
                 short_vendor = tmpA[1]
-        # Add some common vendor aliases
-        if purl.startswith("pkg:composer"):
-            vendor_aliases.add(name)
-        if purl.startswith("pkg:golang") and not name.startswith("go"):
+    # Add some common vendor aliases
+    if purl.startswith("pkg:composer") or purl.startswith("pkg:pypi"):
+        vendor_aliases.add(name)
+    if purl.startswith("pkg:golang") and not name.startswith("go"):
+        # Ignore third party alternatives for builtins
+        if "golang" not in vendor and name not in ["net", "crypto", "http"]:
             vendor_aliases.add("golang")
-        if not purl.startswith("pkg:golang"):
-            vendor_aliases.add("get" + name)
-            vendor_aliases.add(name + "_project")
-        for k, v in config.vendor_alias.items():
-            if vendor.startswith(k) or k.startswith(vendor):
-                vendor_aliases.add(k)
-                vendor_aliases.add(v)
+    if not purl.startswith("pkg:golang"):
+        vendor_aliases.add("get" + name)
+        vendor_aliases.add(name + "_project")
+    for k, v in config.vendor_alias.items():
+        if vendor.startswith(k) or k.startswith(vendor):
+            vendor_aliases.add(k)
+            vendor_aliases.add(v)
+        elif name == k:
+            vendor_aliases.add(v)
     name_aliases.add(name)
     name_aliases.add(name.lower())
     name_aliases.add(name.replace("-", "_"))
@@ -77,6 +81,7 @@ def create_pkg_variations(pkg_dict):
         vendor_aliases.add("pip")
         vendor_aliases.add("python")
         vendor_aliases.add("python-" + name)
+        vendor_aliases.add(name + "project")
     elif purl.startswith("pkg:npm") and not name.startswith("node-"):
         name_aliases.add("node-" + name)
     elif purl.startswith("pkg:crates") and not name.startswith("rust-"):
@@ -130,3 +135,19 @@ def dealias_packages(pkg_list, pkg_aliases):
                 dealias_dict[full_pkg] = k
                 break
     return dealias_dict
+
+
+def dedup(pkg_list, pkg_aliases):
+    """Method to trim duplicates in the results based on the id. The logic should ideally be based on package alias but is kept simple for now.
+
+    :param pkg_list: List of packages to dedup
+    :param pkg_aliases: Package aliases
+    """
+    dedup_dict = {}
+    ret_list = []
+    for res in pkg_list:
+        vid = res.id
+        if vid not in dedup_dict:
+            ret_list.append(res)
+            dedup_dict[vid] = True
+    return ret_list
