@@ -80,6 +80,8 @@ def detect_project_type(src_dir):
         project_types.append("java")
     if find_files(src_dir, ".gradle.kts", quick=True):
         project_types.append("kotlin")
+    if find_files(src_dir, "build.sbt", quick=True):
+        project_types.append("scala")
     if (
         find_files(src_dir, "package.json", quick=True)
         or find_files(src_dir, "yarn.lock", quick=True)
@@ -103,6 +105,24 @@ def detect_project_type(src_dir):
     return project_types
 
 
+def get_pkg_vendor_name(pkg):
+    """
+    Method to extract vendor and name information from package. If vendor information is not available
+    package url is used to extract the package registry provider such as pypi, maven
+    """
+    vendor = pkg.get("vendor")
+    if not vendor:
+        purl = pkg.get("purl")
+        if purl:
+            purl_parts = purl.split("/")
+            if purl_parts:
+                vendor = purl_parts[0].replace("pkg:", "")
+        else:
+            vendor = ""
+    name = pkg.get("name")
+    return vendor, name
+
+
 def search_pkgs(db, pkg_list):
     """
     Method to search packages in our vulnerability database
@@ -115,25 +135,35 @@ def search_pkgs(db, pkg_list):
     for pkg in pkg_list:
         variations = normalize.create_pkg_variations(pkg)
         expanded_list += variations
-        vendor = pkg.get("vendor")
-        if not vendor:
-            purl = pkg.get("purl")
-            if purl:
-                purl_parts = purl.split("/")
-                if purl_parts:
-                    vendor = purl_parts[0].replace("pkg:", "")
-            else:
-                vendor = ""
-        name = pkg.get("name")
+        vendor, name = get_pkg_vendor_name(pkg)
+        # TODO: Use purl here
         pkg_aliases[vendor + ":" + name] = [
             "{}:{}".format(vari.get("vendor"), vari.get("name")) for vari in variations
         ]
     quick_res = dbLib.bulk_index_search(expanded_list)
     raw_results = dbLib.pkg_bulk_search(db, quick_res)
+    raw_results = normalize.dedup(raw_results, pkg_aliases=pkg_aliases)
     pkg_aliases = normalize.dealias_packages(raw_results, pkg_aliases=pkg_aliases)
     return raw_results, pkg_aliases
 
 
+def get_pkgs_by_scope(pkg_list):
+    """
+    Method to return the packages by scope as defined in CycloneDX spec - required, optional and excluded
+
+    :param pkg_list: List of packages
+    :return: Dictionary of packages categorized by scope if available. Empty if no scope information is available
+    """
+    scoped_pkgs = {}
+    for pkg in pkg_list:
+        if pkg.get("scope"):
+            vendor, name = get_pkg_vendor_name(pkg)
+            scope = pkg.get("scope").lower()
+            # TODO: Use purl here
+            scoped_pkgs.setdefault(scope, []).append(f"{vendor}:{name}")
+    return scoped_pkgs
+
+
 def cleanup_license_string(license_str):
     """
     Method to cleanup license string by removing problematic symbols and making certain keywords consistent
@@ -153,8 +183,7 @@ def cleanup_license_string(license_str):
 
 
 def max_version(version_list):
-    """Method to return the highest version from the list
-    """
+    """Method to return the highest version from the list"""
     if isinstance(version_list, str):
         return version_list
     if isinstance(version_list, set):
